The Great Gatsby by F. Scott Fitzgerald | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# The Great Gatsby by F. Scott Fitzgerald

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/64317.html.images | 317 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/64317.epub3.images | 346 kB |  |  |
| EPUB (older E-readers) | https://www.gutenberg.org/ebooks/64317.epub.images | 350 kB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/64317.epub.noimages | 178 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/64317.kf8.images | 456 kB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/64317.kindle.images | 446 kB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/64317.txt.utf-8 | 299 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/64317/pg64317-h.zip | 879 kB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…
In Browsing: Culture/Civilization/Society
In Browsing: Literature
In Browsing: Fiction

## About this eBook

Author | Fitzgerald, F. Scott (Francis Scott), 1896-1940
Title | The Great Gatsby
Note | Reading ease score: 81.6 (6th grade). Easy to read.
Note | Wikipedia page about this book: https://en.wikipedia.org/wiki/The_Great_Gatsby
Credits | Produced by Alex Cabal for the Standard Ebooks project, based on a transcription produced for Project Gutenberg Australia.
Summary | "The Great Gatsby" by F. Scott Fitzgerald is a novel written in the early 20th century. The story is mainly narrated by Nick Carraway, who reflects on the life of his enigmatic neighbor, Jay Gatsby, and the extravagant world of wealth and excess he inhabits. The novel explores themes of the American Dream, love, and social class. At the start of the novel, Nick Carraway reflects on advice from his father about withholding judgment of others, which sets the stage for the unfolding narrative. We learn about Nick's background, his move to West Egg, and his connection to wealthy acquaintances like Tom and Daisy Buchanan. Nick's first glimpse of Gatsby is during a moment of solitude when he sees Gatsby reaching out toward a distant green light, symbolizing his unattainable dreams. This opening portion lays the groundwork for the intricate relationships and social dynamics in the world of 1920s America, hinting at the luxurious yet hollow lives that many characters lead. (This is an automatically generated summary.)
Language | English
LoC Class | PS: Language and Literatures: American and Canadian literature
Subject | Psychological fiction
Subject | First loves -- Fiction
Subject | Married women -- Fiction
Subject | Rich people -- Fiction
Subject | Long Island (N.Y.) -- Fiction
Category | Text
EBook-No. | 64317
Release Date | Jan 17, 2021
Most Recently Updated | Jan 26, 2025
Copyright Status | Public domain in the USA.
Downloads | 31213 downloads in the last 30 days.
Project Gutenberg eBooks are always free!